@@ -9,7 +9,7 @@ sub awx_wx_config_data {
     my %data = %{$self->SUPER::awx_wx_config_data};
 
     # MakeMaker does not like the "-framework foo" options
-    $data{libs} =~ s/-framework\s+\w+//g;
+    $data{libs} =~ s{-framework\s+\w+|-L/usr/local/lib}{}g;
 
     $data{ld} = $data{cxx};
     $data{cxxflags} .= ' -UWX_PRECOMP ';
@@ -17,4 +17,7 @@ sub awx_wx_config_data {
     $self->{awx_data} = \%data;
 }
 
+sub awx_build_toolkit { 'mac' }
+sub awx_dlext { 'dylib' }
+
 1;
